Module scale_encode::utils
source · Expand description
Some utility types that are useful in order to help implement EncodeAsType.
Structs
This type represents named or unnamed composite values, and can be used
to help generate
EncodeAsType impls. It’s primarily used by the exported
macros to do just that.A read-only registry containing types in their portable form for serialization.